@@ -366,10 +366,10 @@ class ArangoDBHelper:
         query = f"""
             FOR doc in @@collection SEARCH doc.type IN @types AND doc._is_latest == TRUE
             {other_filters or ""}
-            {self.get_sort_stmt(SCO_SORT_FIELDS)}
 
             COLLECT id = doc.id INTO docs
             LET doc = FIRST(FOR d in docs[*].doc SORT d.modified OR d.created DESC, d._record_modified DESC RETURN d)
+            {self.get_sort_stmt(SCO_SORT_FIELDS)}
             
             LIMIT @offset, @count
             RETURN KEEP(doc, KEYS(doc, true))
@@ -389,11 +389,11 @@ class ArangoDBHelper:
             FOR doc in @@collection
             SEARCH doc.type IN @types AND doc._is_latest == TRUE
             {other_filters or ""}
-            {self.get_sort_stmt(SMO_SORT_FIELDS)}
 
 
             COLLECT id = doc.id INTO docs
             LET doc = FIRST(FOR d in docs[*].doc SORT d.modified OR d.created DESC, d._record_modified DESC RETURN d)
+            {self.get_sort_stmt(SMO_SORT_FIELDS)}
 
             LIMIT @offset, @count
             RETURN  KEEP(doc, KEYS(doc, true))
@@ -436,11 +436,11 @@ class ArangoDBHelper:
             FOR doc in @@collection
             SEARCH doc.type IN @types AND {' AND '.join(search_filters)}
             {other_filters or ""}
-            {self.get_sort_stmt(SDO_SORT_FIELDS)}
 
             
             COLLECT id = doc.id INTO docs
             LET doc = FIRST(FOR d in docs[*].doc SORT d.modified OR d.created DESC, d._record_modified DESC RETURN d)
+            {self.get_sort_stmt(SDO_SORT_FIELDS)}
 
             LIMIT @offset, @count
             RETURN  KEEP(doc, KEYS(doc, true))
@@ -470,7 +470,7 @@ class ArangoDBHelper:
             "id": stix_id,
         }
         rel_search_filters = []
-        search_filters = []
+        late_filters = []
         if not self.query_as_bool("include_embedded_refs", True):
             rel_search_filters.append("doc._is_ref != TRUE")
 
@@ -478,10 +478,18 @@ class ArangoDBHelper:
             rel_search_filters.append(
                 "(doc._target_type IN @types OR doc._source_type IN @types)"
             )
-            search_filters.append("FILTER doc.type IN @types")
+            late_filters.append("FILTER doc.type IN @types")
             bind_vars["types"] = types
 
+        if not self.query_as_bool('include_embedded_sros', False):
+            late_filters.append('FILTER doc._is_ref != TRUE')
+        
         visible_to_filter = ""
+        
+        if created_by_refs := self.query_as_array("created_by_refs"):
+            late_filters.append("FILTER doc.created_by_ref IN @created_by_refs OR doc.id == @id")
+            bind_vars["created_by_refs"] = created_by_refs
+            
         if q := self.query.get("visible_to"):
             bind_vars["visible_to"] = q
             bind_vars["marking_visible_to_all"] = (
@@ -503,37 +511,13 @@ class ArangoDBHelper:
             query = query.replace(
                 "/* rel_search_extras */", " AND " + " AND ".join(rel_search_filters)
             )
-        if search_filters:
-            query = query.replace("// extra_search", "\n".join(search_filters))
+        if late_filters:
+            query = query.replace("// extra_search", "\n".join(late_filters))
 
         if visible_to_filter:
             query = query.replace("// visible_to_filter", visible_to_filter)
         return self.execute_query(query, bind_vars=bind_vars)
 
-    def get_containing_reports(self, id):
-        bind_vars = {
-            "@view": self.collection,
-            "id": id,
-        }
-        more_filters = []
-        if created_by_refs := self.query_as_array("identity_ids"):
-            more_filters.append("FILTER report.created_by_ref IN @created_by_refs")
-            bind_vars["created_by_refs"] = created_by_refs
-        query = """
-            LET report_ids = (
-                FOR doc in @@view
-                FILTER doc.id == @id
-                RETURN DISTINCT doc._stixify_report_id
-            )
-            FOR report in @@view
-            SEARCH report.type == 'report' AND report.id IN report_ids
-            #more_filters
-            LIMIT @offset, @count
-            RETURN KEEP(report, KEYS(report, TRUE))
-        """
-        query = query.replace("#more_filters", "\n".join(more_filters))
-        return self.execute_query(query, bind_vars=bind_vars)
-
     def get_sros(self):
         bind_vars = {
             "@collection": self.collection,
@@ -583,10 +567,10 @@ class ArangoDBHelper:
         query = f"""
             FOR doc in @@collection
             SEARCH doc.type == 'relationship' AND { ' AND '.join(search_filters) }
-            {self.get_sort_stmt(SRO_SORT_FIELDS)}
 
             COLLECT id = doc.id INTO docs
             LET doc = FIRST(FOR d in docs[*].doc SORT d.modified OR d.created DESC, d._record_modified DESC RETURN d)
+            {self.get_sort_stmt(SRO_SORT_FIELDS)}
 
             LIMIT @offset, @count
             RETURN KEEP(doc, KEYS(doc, true))
