@@ -20,6 +20,7 @@ from django.conf import settings
 
 import textwrap
 
+
 OBJECT_ID_PATTERN = (
     r"[\w\-]+--[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
 )
@@ -152,6 +153,12 @@ class QueryParams:
         type=OpenApiTypes.BOOL,
     )
 
+    include_embedded_sros = OpenApiParameter(
+        "include_embedded_sros",
+        type=OpenApiTypes.BOOL,
+        description="set to `true` to include the embedded relationships linking the objects. Setting to `false` (default) will still return the target object, but wont return the embedded SRO linking them. Set to `true` if your downstream software CANNOT interpret STIX embedded relationships",
+    )
+
     SRO_PARAMS = [
         source_ref,
         source_ref_type,
@@ -207,13 +214,13 @@ class QueryParams:
         type=OpenApiTypes.STR,
     )
 
-    identity_ids = OpenApiParameter(
-        "identity_ids",
+    created_by_refs = OpenApiParameter(
+        "created_by_refs",
         many=True,
         explode=False,
         description=textwrap.dedent(
             """
-            Filter the results by the objects `created_by_ref` property. Pass an Identity object ID here, e.g. `identity--6ae57ee1-39c9-4c6b-88a9-1d73d9efff7f`.
+            Filter the results by the objects `created_by_ref` property. Pass one of more Identity object IDs, e.g. `identity--6ae57ee1-39c9-4c6b-88a9-1d73d9efff7f`. The results will only contained objects created by that ID.
             """
         ),
     )
@@ -247,7 +254,9 @@ class QueryParams:
             QueryParams.object_id_param,
             QueryParams.all_types,
             QueryParams.include_embedded_refs,
+            QueryParams.include_embedded_sros,
             QueryParams.visible_to,
+            QueryParams.created_by_refs,
         ],
     ),
 )
@@ -269,31 +278,6 @@ class SingleObjectView(viewsets.ViewSet):
 
 
 @extend_schema_view(
-    reports=extend_schema(
-        responses=ArangoDBHelper.get_paginated_response_schema(
-            "reports",
-            {
-                "type": "object",
-                "properties": {
-                    "type": {
-                        "example": "report",
-                    },
-                    "id": {
-                        "example": "report--a86627d4-285b-5358-b332-4e33f3ec1075",
-                    },
-                },
-                "additionalProperties": True,
-            },
-        ),
-        parameters=ArangoDBHelper.get_schema_operation_parameters()
-        + [QueryParams.object_id_param, QueryParams.identity_ids],
-        summary="Get all Reports that contain this STIX Object",
-        description=textwrap.dedent(
-            """
-            Return all reports the STIX Object has a Relationship to.
-            """
-        ),
-    ),
     destroy_in_report=extend_schema(
         summary="Delete an Object from a Report",
         description=textwrap.dedent(
@@ -310,11 +294,6 @@ class SingleObjectView(viewsets.ViewSet):
     ),
 )
 class ObjectsWithReportsView(SingleObjectView):
-    @decorators.action(detail=True, methods=["GET"])
-    def reports(self, request, *args, **kwargs):
-        return ArangoDBHelper(
-            conf.ARANGODB_DATABASE_VIEW, request, "reports"
-        ).get_containing_reports(kwargs.get(self.lookup_url_kwarg))
 
     @decorators.action(
         detail=True,
